pub struct IntersectionResult {
pub truechimers: Vec<usize>,
pub falsetickers: Vec<usize>,
pub low: NtpDuration,
pub high: NtpDuration,
}Expand description
Result of Marzullo’s intersection algorithm.
Fields
truechimers: Vec<usize>Indices of sources whose intervals overlap the intersection (truechimers).
falsetickers: Vec<usize>Indices of sources whose intervals do not overlap (falsetickers).
low: NtpDurationLower bound of the final intersection interval.
high: NtpDurationUpper bound of the final intersection interval.